==> pyfilesysobjects-0.0.2.tar.gz: pyfilesysobjects-0.0.2/UseCases/filesysobjects/FileSysObjects/getSourceLinenumber/CallCase.py <==
"""Get the caller name.
"""
from __future__ import absolute_import
from __future__ import print_function

__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2010-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.0.1'
__uuid__='af90cc0c-de54-4a32-becd-06f5ce5a3a75'

__docformat__ = "restructuredtext en"

import unittest
import os,sys

#
# set search for the call of 'myscript.sh'
from filesysobjects.FileSysObjects import setUpperTreeSearchPath
setUpperTreeSearchPath(None,'UseCases')

import filesysobjects.FileSysObjects

#
#######################
#

class CallUnits(unittest.TestCase):
    name=os.path.curdir+__file__

    output=True
    output=False

    def testCase000(self):
        ret = filesysobjects.FileSysObjects.getSourceLinenumber()
        retx = 35
        assert retx == ret

    def testCase001(self):
        ret = filesysobjects.FileSysObjects.getSourceLinenumber(1)
        retx = 40
        assert retx == ret

    def testCase002(self):
        ret = filesysobjects.FileSysObjects.getSourceLinenumber(2)
        retx = 369
        assert retx == ret

    def testCase003(self):
        ret = filesysobjects.FileSysObjects.getSourceLinenumber(3)
        retx = 433
        assert retx == ret

    def testCase004(self):
        ret = filesysobjects.FileSysObjects.getSourceLinenumber(4)
        retx = 116
        assert retx == ret

#
#######################
#

if __name__ == '__main__':
    unittest.main()

==> pyfilesysobjects-0.0.4.tar.gz: pyfilesysobjects-0.0.4/UseCases/filesysobjects/FileSysObjects/getSourceLinenumber/CallCase.py <==
"""Get the caller name.
"""
from __future__ import absolute_import
from __future__ import print_function

__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2010-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.0.1'
__uuid__='af90cc0c-de54-4a32-becd-06f5ce5a3a75'

__docformat__ = "restructuredtext en"

import unittest
import os

#
# set search for the call of 'myscript.sh'
from filesysobjects.FileSysObjects import setUpperTreeSearchPath
setUpperTreeSearchPath(None,'UseCases')

import filesysobjects.PySourceInfo

#
#######################
#

class CallUnits(unittest.TestCase):
    name=os.path.curdir+__file__

    output=True
    output=False

    def testCase000(self):
        ret = filesysobjects.PySourceInfo.getSourceLinenumber()
        retx = 35
        assert retx == ret

    def testCase001(self):
        ret = filesysobjects.PySourceInfo.getSourceLinenumber(1)
        retx = 40
        assert retx == ret

    def testCase002(self):
        ret = filesysobjects.PySourceInfo.getSourceLinenumber(2)
        retx = 369
        assert retx == ret

    def testCase003(self):
        ret = filesysobjects.PySourceInfo.getSourceLinenumber(3)
        retx = 433
        assert retx == ret

    def testCase004(self):
        ret = filesysobjects.PySourceInfo.getSourceLinenumber(4)
        retx = 116
        assert retx == ret

#
#######################
#

if __name__ == '__main__':
    unittest.main()
